@@ -1,8 +1,8 @@
 #!/usr/local/bin/perl -w 
 use blib;
 use strict;
-use Geo::Storm_Tracker::Parser;
-use Geo::Storm_Tracker::Data;
+use Geo::StormTracker::Parser;
+use Geo::StormTracker::Data;
 
 my ($success,$error,$result,$data_obj,$advisory,$parser,$adv_obj,$path,$position_track_AR)=undef;
 my ($string,$position_AR)=undef;
@@ -11,7 +11,7 @@ my $using_path=undef;
 #$result=join('--',@{$adv_obj->movement_toward()});
 
 $path='/home/newemd/emdjlc/hurricane/Storm-Tracker/atlantic/1999/11/';
-($data_obj,$error)=Geo::Storm_Tracker::Data->new($path);
+($data_obj,$error)=Geo::StormTracker::Data->new($path);
 
 &_print_var("data_obj",$data_obj);
 &_print_var("error",$error);
